@@ -3,9 +3,10 @@ package Fey::Object::Schema;
 use strict;
 use warnings;
 
+use Fey::Meta::Class::Table;
 use MooseX::StrictConstructor;
 
-extends 'Moose::Object';
+extends 'MooseX::Object::StrictConstructor';
 
 
 sub EnableObjectCaches
